.TH CYCDECO l
.ER
.SH NAME
cycdeco \- calculate cycle and u-path bases of undirected unweighted graphs
.SH SYNOPSIS
\fBcycdeco [\-l] [\-U \fIunodefile\fP]	[\-m|r|u] [\-q] [\-s] [\-h|?]
\fIgraphfile\fP

.SH DESCRIPTION
.I cycdeco
reads undirected unweighted graphs from \fIgraphfile\fP,
containing a graph in \fIGML-Format\fP
(http://www.infosun.fmi.uni-passau.de/Graphlet/GML/)
and calculates a minimum cycle bases, the set of relevant cycles, the set of
shortest and unique shortest and essential cycles, the interchangeability
classes of relevant cycles. If the option \-U is given, the nodes in the
\fIunodefile\fP are taken as endnodes for U-paths and the analog cycle and
U-path sets are calculated.
.br
The cycles and paths are written on a file called "\fIgraphfile\fP.cycles" in
the following format: (for each cycle a line)
.br
cyclenumber	 prototypenumber  interchangeabilityclass length  <member>
cyclenodes
.br
The 8 flags in <member> gave the membership in the different cycle/path 
sets: .br
   1 ... prototype cycles (paths)
.br
   2 ... minimum cycles (paths) bases
.br
   3 ... relevant cycles (paths)
.br
   4 ... shortest cycles (paths)
.br
   5 ... unique shortest cycles (paths)
.br
   6 ... essential cycles (paths)
.br
   7 ... (empty flag)
.br
   8 ... is a path
.br
Of course, all cycles and paths have the third flag set.
.br
example:
.br
 1  1  1  3  < 1 1 1 1 1 1 0 0 >  3 1 2 3
.br
(This triangle has the cycle number 1, the prototype number 1 and is contained
in the interchangeability class number 1. It is a prototype, in the calculated
minimum cycle basis, is a relevant, shortest, unique shortest and essential
cycle, but not a path. The triangle contains the nodes 1, 2 and 3.)
.br
.B Note. \fIcycdeco\fP takes the last argument as \fIgraphfile\fP.
.br
.SH OPTIONS
.TP
.B \-l
\fIgraphfile\fP contains a list of of \fIGML-graph\fP files, separated by
newline. The calculations are done separately for each file in the list. The
output is also given separately for each file
.TP
.B \-U \fIunodefile\fP
Calculate the cycle and U-path bases. \fIunodefile\fP has to contain the
ids of the nodes (just integers) of the graph separated by spaces, e.g.: 1 5 9.
.TP
.B \-m
Do not calculate all cycle (path) sets, but only a minimum
cycle (path) bases.
.TP
.B \-r
Do not calculate all cycle (path) sets, but only a minimum
cycle (path) bases and the set of relevant cycles (paths).
.TP
.B \-u
Do not calculate the interchangeability classes and essential cycles (paths).
.TP
.B \-q
All calculations are done, but the cycles and paths are not written to a file.
This option is only reasonalbe, if just length distributions are needed and
therefore -s is given.
.TP
.B \-s
Calculate a length distribution of the cycles and paths and write it into a file
called "\fIgraphfile\fP.cycle_stat", not deleting the file, just appending on
the end.
In the first line the appearing length are given, then the distributions for a
minimum cycle (path) basis, the set of relevant, shortest, unique shortest and
essential cycles (paths) are given.
.TP
.B \-h \-?
Display a short help message and exit

.SH REFERENCES
The calculation of the minium cycle bases is based on an algorithm originally
developed by J. D. Horton, modified by Ph. Vismara. The algorithm for the
prototypes of relevant cycles and relevant cycles is based on work by Ph.
Vismara. The calculation of the interchangeability classes and the concept of
U-Path bases is based on work by P. M. Gleiss and J. Leydold and P. F. Stadler.
If you use this program in your work you might want to cite:
.PP
P. M. Gleiss and P. F. Stadler.
"Relevant cycles in biopolymers and random graphs.
Presented at the Fourth Slovene International Conference in Graph
Theory, Bled, Slovenia (Santa Fe Institute Preprint 99-07-042,
http://www.santafe.edu}), 1999.
.br
P. M. Gleiss, J. Leydold, and P. F. Stadler
"Interchangeability of relevant cycles in graphs"
"Elec. J. Comb.}, 7:R16 [16pages], 2000
(See http://www.combinatorics.org)
.br
P. M. Gleiss, J. Leydold, and P. F. Stadler
"A note On Minimum Path Bases"
.br
J. D. Horton
"A polynomial-time algorithm to find the shortest cycle basis of a graph."
SIAM J. Comput., 16:359--366, 1987
.br
P. Vismara
"Union of all the minimum cycle bases of a graph"
Electr. J. Comb.}, 4:73--87, 1997
(Paper No. #R9 (15 pages), see http://www.combinatorics.org)
.SH VERSION
This man page documents version 0.1 cycdeco.
.SH AUTHORS
Petra M. Gleiss
.SH BUGS
Comments should be sent to pmg@tbi.univie.ac.at.
COPYRIGHT
       Copyright (c) 2001 Petra M. Gleiss