/***************************************************************************
                          component.cpp  -  description
                             -------------------
    begin                : Thu June 29 2001
    copyright            : (C) 2001 by Gleiss Petra Manuela
    email                : petra@gleiss.at
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "component.h"

#include <algorithm>

namespace graphlib {

//---------------------------------------------------------------------------
// Con-/Destructors
//---------------------------------------------------------------------------
Component::Component(const Graph* g, int n) : SubGraph(g,n), comp_nr(0)
{ component = NULL; }

Component::Component(const Graph* g, constNodeIter begin, constNodeIter end, int n)
    : SubGraph(g,n), comp_nr(0)
{
  component = NULL;
  number_ = n;

  nodes.clear();
  edges.clear();

  constNodeIter it = begin;

  while (it != end)
  {
    // adding nodes
    nodes.push_back(*it);

    // adding adjacent edges
    constEdgeIter edge;
    for (edge = it->adjBegin(); edge!=it->adjEnd(); edge++)
      if (findNode(it->opposite(*edge).id()) != nodes.end())
        edges.push_back(*edge);

    it++;
  }
  nodes.sort();
}

Component::Component(const Graph* g, constEdgeIter begin, constEdgeIter end, int n)
    : SubGraph(g,n), comp_nr(0)
{
  component = NULL;
  number_ = n;

  nodes.clear();
  edges.clear();

  constEdgeIter it = begin;

  while (it != end)
  {
    Node node;

    // add source of edge, if not already in nodes-list
    node = it->source();
    if (find(nodes.begin(),nodes.end(),node) ==  nodes.end())
      nodes.push_back(node);

    // add target of edge, if not already in nodes-list
    node = it->target();
    if (find(nodes.begin(),nodes.end(),node) ==  nodes.end())
      nodes.push_back(node);

    // add edge
    edges.push_back(*it);
    it++;
  }
  nodes.sort();
}

Component::Component(const Component& sub) : BasisGraph(sub),
                                             SubGraph(sub),
                                             comp_nr(sub.comp_nr),
                                             component(sub.component)
{ ; }

Component::~Component()
{ ; }

//---------------------------------------------------------------------------
// Operators
//---------------------------------------------------------------------------
Component& Component::operator= (const Component& g)
{
  if (this == &g) return *this;
  SubGraph::operator=(g);
  comp_nr=g.comp_nr;
  component=g.component;
  return *this;
}

//---------------------------------------------------------------------------
// Information
//---------------------------------------------------------------------------


} // namespace graphlib

/* end of file */
