/***************************************************************************
                          Dot2Gml.h  -  description
                             -------------------
    begin                : Sat Jul 28 2001
    copyright            : (C) 2001 by Petra Gleiss
    email                : petra@gleiss.at
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef DOT2GML_H
#define DOT2GML_H

#include "graphlib_error.h"
using namespace graphlibError;

#include "graph.h"

#include <fstream>
#include <string>
#include <vector>

namespace graphlib {

/**
  *@internal
  */

class Dot2Gml
{

  public:
    //------------------------------------------------------ Con-/Destructors
    /**
      * Generates an NULL-pointer ifstream
      */
    Dot2Gml() {in = 0; structure="";}

    /**
      * Closes ifstream and deletes it
      */
    ~Dot2Gml();

    /**
      * Initialize a new ifstream binding on the file <code>fname</code>
      *
      * @param <code>fname</code> name of logfile
      */
    void init(string fname) throw(FileError);

    //------------------------------------------------------ Methods
    /**
      * Reads the dot-bracket structure form the file bound to the
      * <var>in</var>, generates an undirected Graph and stores it
      * in <code>graph</code>.
      * <em>Note</em>
      * <code>graph</code> will be cleared at first.
      *
      * @param graph
      */
    void dot2gml(Graph& graph) throw(FileError,SyntaxError);

   private:
    //------------------------------------------------------ ofstrem
    ifstream *in;

    /// dot-bracket string
    string structure;

    //------------------------------------------------------ ofstrem
    // reads file -> structure
    void readStructure() throw(FileError);
    // makes from structure -> graph
    void makeGraph(Graph&) throw(SyntaxError);

}; // class Dot2Gml

} // namespace graphlib
#endif // DOT2GML_H

/* end of file */
