/***************************************************************************
                          edge.cpp  -  description
                             -------------------
    begin                : Thu Mar 1 2001
    copyright            : (C) 2001 by Gleiss Petra Manuela
    email                : petra@gleiss.at
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "edge.h"
#include "nodedata.h"
#include "edgedata.h"
#include "trace.h"

namespace graphlib {

//---------------------------------------------------------------------------
// Con-/Destructors
//---------------------------------------------------------------------------
Edge::Edge() : data_(0)
{
}
//---------------------------------------------------------------------------
// Operators
//---------------------------------------------------------------------------
bool Edge::operator==(const Edge& e) const
{
  return (data_ == e.data_);
}
bool Edge::operator!=(const Edge& e) const
{
  return (data_ != e.data_);
}
bool Edge::operator<(const Edge& e) const
{
  return (data_ < e.data_);
}

//---------------------------------------------------------------------------
// Input / Output
//---------------------------------------------------------------------------
ostream& operator<<(ostream& os, const Edge& e)
{
  return os << e.source().id() << "-->" << e.target().id();
}

//---------------------------------------------------------------------------
// Information
//---------------------------------------------------------------------------
string Edge::label() const
{
  return data()->label;
}

constEdgeIter Edge::pos() const
{
  return data()->pos;
}

Node Edge::source() const
{
  return *(data()->nodes.begin());
}

Node Edge::target() const
{
  return *(++(data()->nodes.begin()));
}

void Edge::removeFrom()
{
  NodeIter theNodes    = data()->nodes.begin();
  NodeIter theNodesEnd = data()->nodes.end();

  list<EdgeIter>::iterator theAdjPos;

  theAdjPos = data_->adj_pos.begin();

  while(theNodes != theNodesEnd)
  {
    theNodes->data()->edges.erase(*theAdjPos);
    theNodes->data()->degree--;

    ++theNodes;
    ++theAdjPos;
  }
}

//---------------------------------------------------------------------------
// Set Functions
//---------------------------------------------------------------------------
constEdgeIter Edge::label(string label)
{
  data()->label = label;
  return data()->pos;
}

//---------------------------------------------------------------------------
// Private Functions
//---------------------------------------------------------------------------
EdgeData const* Edge::data() const throw(EmptyEdgeError)
{
  if (!data_)
    THROW(EmptyEdgeError,"Edge::data() const")
  return data_;
}

EdgeData* Edge::data() throw(EmptyEdgeError)
{
  if (!data_)
    THROW(EmptyEdgeError,"Edge::data()")
  return data_;
}

} // namespace graphlib

/* end of file */
