/***************************************************************************
                          gml_parser.h  -  description
                             -------------------
    begin                :
    copyright            : (C) 1997 by Michael Himsolt
    email                : himsolt@fmi.uni-passau.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef GML_PARSER_H
#define GML_PARSER_H

#include "gml_scanner.h"
#include <iostream>

namespace graphlib {

/**
  @internal
  */
union GML_pair_val
{
    long integer;
    double floating;
    char* str;
    struct GML_pair* list;
};

/**
  @internal
  */
struct GML_pair
{
    char* key;
    GML_value kind;
    int lineNr;
    union GML_pair_val value;
    struct GML_pair* next;
};

/**
  @internal
  */
struct GML_list_elem
{
    char* key;
    int lineNr;
    struct GML_list_elem* next;
};

/**
  @internal
  */
struct GML_stat
{
    struct GML_error err;
    struct GML_list_elem* key_list;
};

/**
  * returns list of KEY - VALUE pairs. Errors and a pointer to a list
  * of key-names are returned in GML_stat. Previous information contained
  * in GML_stat, i.e. the key_list, will be *lost*.
  */
struct GML_pair* GML_parser (FILE*, struct GML_stat*, int);

/**
  * free memory used in a list of GML_pair
  */
void GML_free_list (struct GML_pair*, struct GML_list_elem*);


/**
  * debugging
  */
void GML_print_list (struct GML_pair*, int);

/**
  * debugging
  */
void GML_printList(struct GML_pair*, int, ostream&);

/**
  * error
  */
char* GML_print_error (struct GML_stat*,const char* filename);

} // namespace graphlib

#endif // GML_PARSER_H

/* end of file */





