/***************************************************************************
                          graphlib_utilities.cpp  -  description
                             -------------------
    begin                : Wed Jun 6 2001
    copyright            : (C) 2001 by Gleiss Petra Manuela
    email                : petra@gleiss.at
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "graphlib_utilities.h"
#include "graphlib.h"
#include "utilities.h"
#include "logfile.h"

#include "bitvector.h"

namespace graphlib {

//---------------------------------------------------------------------------
// gauss elimination
//---------------------------------------------------------------------------
int gauss(list<BitVector>& v, list<BitVector>::iterator posy, int posx)
{
  list<BitVector>::iterator i = posy;
  int size = v.begin()->getsize();

  if (posy!=v.end() && (posx<size))
  {
    try
    {
      // search for the first line with a "1" in column posx
      while (! i->getBit(posx))
      {
        i++;
        // no "1" in this column
        if (i==v.end())
        {
          // next column
          posx++;
          return gauss(v, posy, posx);
        }
      }
      // reorder -> change positions of these two lines
      if (i!=posy)
        iter_swap(i,posy);

    }
    catch (logic_error& e)
    {
      cout << "*************** F E H L E R GAUSS *************\n";
      cout << e.what() << endl;
      v.erase(posy,v.end());
      return v.size();
    }

    // XOR all line where in column posx "1"
    for (i=v.begin(); i!=v.end(); i++)
      if (i->getBit(posx) && i!=posy)
        *i ^= *posy;

    posy++;posx++;
    return gauss(v, posy, posx);
  }

  // END
  else
  {
    // remove all empty BitVectors
    v.erase(posy,v.end());
    return v.size();
  }
}

//---------------------------------------------------------------------------
// gauss elimination
//---------------------------------------------------------------------------
int gaussJordan(list<BitVector>& matrix, list<BitVector>::iterator pos, int posx)
{
  // pos = Pivot-row
  list<BitVector>::iterator i, posy=pos;
  // number of colums
  int size=(*matrix.begin()).getsize();

  // last row or last column reached -> END of the recursion
  if (posx == size || pos==matrix.end())
  {
    // remove all empty BitVectors at the end
    matrix.erase(pos,matrix.end());

    // rank == size of the matrix
    return matrix.size();
  }

  // do the gauss/jordan elimination
  else
  {
    // search for the first line with a "1" in the posx. column
    while (!posy->getBit(posx))
    {
      // next row
      posy++;

      // reached the last row - no "1" in this column
      if (posy==matrix.end())
        // try the next column
        return gaussJordan(matrix,pos,++posx);
    }

    // reorder -> change positions of these two lines
    if (posy!=pos)
      iter_swap(pos,posy);

    // "remove" "1" from all rows, except pivot-row, by XOR
    for (i=matrix.begin();i!=matrix.end();i++)
    {
      if (i!=pos && i->getBit(posx))
	      *i ^= *pos;
    }

    // recursive call with the next row and column
    return gaussJordan(matrix,++pos,++posx);
  }

  throw logic_error("gaussJordan() - unexpected part of the function!");
}




} // namespace graphlib

/* end of file */
