/***************************************************************************
                          prototype.cpp  -  description                              
                             -------------------                                         
    begin                : Thu Dec 30 1999                                           
    copyright            : (C) 1999 by Gleiss Petra                         
    email                : petra@gleiss.at                                     
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   * 
 *                                                                         *
 ***************************************************************************/


#include "prototype.h"

namespace graphlib {

//---------------------------------------------------------------------------
// Con-/Destructors
//---------------------------------------------------------------------------
Prototype::Prototype(unsigned asize, const Graph* g) :  Cycle(asize, g),
              r_(INFINITY), p_(INFINITY), q_(INFINITY),
              x_(INFINITY), y_(INFINITY) {;}

Prototype::Prototype(const Cycle& aP) : BasisGraph(aP), Cycle(aP),
              r_(INFINITY), p_(INFINITY), q_(INFINITY),
              x_(INFINITY), y_(INFINITY) {;}

Prototype::Prototype(const Prototype& aP) : BasisGraph(aP), Cycle(aP),
              r_(aP.r_), p_(aP.p_), q_(aP.q_), x_(aP.x_), y_(aP.y_) {;}

//---------------------------------------------------------------------------
// Operators
//---------------------------------------------------------------------------
Prototype& Prototype::operator=(const Prototype& aP)
{
  if (this == &aP) return *this;
  Cycle::operator=(aP);

  r_ = aP.r_;
  p_ = aP.p_;
  q_ = aP.q_;
  x_ = aP.x_;
  y_ = aP.y_;
  return *this;
}

//---------------------------------------------------------------------------
// IO
//---------------------------------------------------------------------------
ostream& operator<< (ostream& os, const Prototype& aP)
{
  unsigned i;
  os << "  " << aP.index();
  os << "  " << aP.prototypeIndex();
  os << "  " << aP.count() << " < ";
  for (i=0;i<8;i++)
  {
    if (aP.getmembers((Cycle::MemberFlag)i)) os << "1 ";
    else os << "0 ";
  } //for
  os << ">  ";

  // cycles
  if (!aP.getmembers(Cycle::UPath))
  {
    os << aP.r() << "  " << aP.p() << "  " << aP.q() << "  " ;
    if (aP.x()!=INFINITY) os << aP.x() << "  ";
    if (aP.y()!=INFINITY) os << aP.y() << "  ";
  }
  // paths
  else
  {
    os << aP.p() << "  " << aP.q() << "  ";
    if (aP.r()!=INFINITY) os << aP.r() << "  ";
    os << aP.x() << "  " << aP.y() << "  ";
  }

  for (i=0;i<aP.getsize();i++)
  {
    if ((i%4)==0) os << " ";
    if (i%BITS==0) os << "| ";
    if (aP.getBit(i))
      os << "1";
    else
      os << "0";
  } //for
/*  os << " | (";
  for (i=aP.getsize();i!=BITS*aP.getwords();i++) {
    if ((i%4)==0 && i!=aP.getsize()) os << " ";
    os << (aP.getbuffer()[i/BITS] & (0x1 << BITS-1-i%BITS)) ;
  }//for
  os << ")" << endl;*/

  os << "|\t" << (aP.cycleNodes()) << endl ;
  return os;
}


//---------------------------------------------------------------------------
// IO
//---------------------------------------------------------------------------
Prototype& Prototype::setNodes(int ar, int ap, int aq, int ax, int ay) {
  r_ = ar; p_ = ap; q_ = aq; x_ = ax; y_ = ay;
  return *this;
}

// additional functions

// friend functions //////////////////////////////////////////////////////////
} // namespace graphlib

/* end of file */
