/***************************************************************************
                          subgraph.cpp  -  description
                             -------------------
    begin                : Thu June 29 2001
    copyright            : (C) 2001 by Gleiss Petra Manuela
    email                : petra@gleiss.at
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#include "subgraph.h"

#include "nodedata.h"
#include "nodeid.h"

#include "edgedata.h"
#include "edgeid.h"

#include "utilities.h"
#include "trace.h"
#include "logfile.h"

#include <algorithm>

namespace graphlib {

//---------------------------------------------------------------------------
// Con-/Destructors
//---------------------------------------------------------------------------
SubGraph::SubGraph(const Graph* g, int nr) :  BasisGraph(nr),
                                              graph(g)
{ ; }

SubGraph::SubGraph(const SubGraph& sub) : BasisGraph(sub),
                                          graph(sub.graph)
{ ; }

//---------------------------------------------------------------------------
// Operators
//---------------------------------------------------------------------------
SubGraph& SubGraph::operator= (const SubGraph& g)
{
  if (this == &g) return *this;

  BasisGraph::operator=(g);
  graph = g.graph;
  return *this;
}

void SubGraph::add(const Node& node) throw(DoubleError,EmptyNodeError)
{
  if (node.isNULL())
    THROW(EmptyNodeError,"SubGraph::add(const Node&)")

  if (find(nodes.begin(),nodes.end(),node) != nodes.end())
    THROW(DoubleError,"SubGraph::add(const Node&): "+Ttos(node)+" twice")

  nodes.push_back(node);
}

void SubGraph::add(const Edge& edge)
    throw(DoubleError,EmptyNodeError,EmptyEdgeError)
{
  if (find(edges.begin(),edges.end(),edge) != edges.end())
    THROW(DoubleError,"SubGraph::add(const Edge&): "+Ttos(edge)+" twice")

  if (find(nodes.begin(),nodes.end(),edge.source()) == nodes.end())
    THROW(EmptyNodeError,"SubGraph::add(const Edge&): "+Ttos(edge.source())+
          " not in the subgraph")

  if (find(nodes.begin(),nodes.end(),edge.target()) == nodes.end())
    THROW(EmptyNodeError,"SubGraph::add(const Edge&): "+Ttos(edge.target())+
          " not in the subgraph")

  edges.push_back(edge);
}


} // namespace graphlib

/* end of file */
