/***************************************************************************
                          trace.h  -  description
                             -------------------
    begin                : Tue Mar 28 2000
    copyright            : (C) 2000 by Juergen Gleiss
    email                : juergen@gleiss.at
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef TRACE_H
#define TRACE_H

#include <fstream>
#include <stdexcept>
#include <string>

#include "graphlib.h"

namespace graphlib {

/**
  * class for logging exceptions
  *
  */
class Trace
{
public:
    //------------------------------------------------------ Con-/Destructors
    /**
      * Generates an NULL-pointer ofstream
      */
    Trace() { out=0; }

    /**
      * Closes ofstream and deletes it
      */
    ~Trace();

    /**
      * Initialize a new ofstream binding on the file <code>fname</code>
      *
      * @param <code>fname</code> name of logfile
      */
    void init(string fname) throw(logic_error);

    //------------------------------------------------------ Methods
    /**
      * Writes the three parameters and the date into the logfile
      * <code>fname</code>
      *
      * @param <code>fname</code> name of file where exception was thrown
      * @param <code>line</code> line of in file where exception was thrown
      * @param <code>exeption</code> kind of exception
      * @param <code>msg</code> message of the throw statement
      */
    string logging(string fname, int line, string exeption, string msg);

    /**
      * Writes the three parameters and the date into the logfile
      * <code>fname</code>
      *
      * @param <code>fname</code> name of file where exception was thrown
      * @param <code>line</code> line of in file where exception was thrown
      * @param <code>exeption</code> kind of exception
      * @param <code>msg</code> message of the throw statement
      */
    string logging(string fname, string line, string exeption, string msg);

    /**
      * Returns ostream&
      */
    ostream& os() { return *out;}

    /**
      * Returns true if initialized.
      */
    bool isInit() const { return (out==NULL) ? false : true;}

  protected:
    //------------------------------------------------------ ofstrem
    ofstream *out;

}; // class Trace

} // namespace graphlib

  extern graphlib::Trace trace;

  //------------------------------------------------------ some macros

  #ifdef GRAPHLIB_TRACE
    #define TRACE(msg)\
      trace.logging(__FILE__,__LINE__,"trace",msg);
    #define INIT_TRACE(fname) trace.init(fname);

  #else
    #define TRACE(msg) {;}
    #define INIT_TRACE(fname) {;}
  #endif

  #define THROW(e, msg)\
    throw (e(trace.logging(__FILE__,__LINE__,#e,msg)));

#endif // TRACE_H

/* end of file */







































